Country

Struct Country 

pub struct Country {
Show 29 fields pub iso_code: &'static str, pub alpha3: &'static str, pub continent: &'static str, pub continent_code: &'static str, pub country_code: &'static str, pub currency_code: &'static str, pub distance_unit: &'static str, pub economic_unions: &'static [&'static str], pub gec: &'static str, pub geo: Geo, pub international_prefix: &'static str, pub ioc: &'static str, pub iso_long_name: &'static str, pub iso_short_name: &'static str, pub languages_official: &'static [&'static str], pub languages_spoken: &'static [&'static str], pub national_destination_code_lengths: &'static [u8], pub national_number_lengths: &'static [u8], pub national_prefix: Option<&'static str>, pub nationality: &'static str, pub number: &'static str, pub postal_code: bool, pub postal_code_format: &'static str, pub region: &'static str, pub start_of_week: &'static str, pub subregion: &'static str, pub un_locode: &'static str, pub unofficial_names: &'static [&'static str], pub world_region: &'static str,
}
Country information.

Fields

iso_code: &'static str

The ISO 3166-1 alpha-2 code of the country.

alpha3: &'static str

The ISO 3166-1 alpha-3 code of the country.

continent: &'static str

The continent the country is located in.

continent_code: &'static str

The continent code.

country_code: &'static str

The country code.

currency_code: &'static str

The currency code used in the country.

distance_unit: &'static str

The distance unit used in the country.

economic_unions: &'static [&'static str]

The economic unions the country is part of.

gec: &'static str

The GEC (Geographic Encoding Class) code.

geo: Geo

The geographic information.

international_prefix: &'static str

The international dialing prefix.

ioc: &'static str

The IOC (International Olympic Committee) code.

iso_long_name: &'static str

The long name of the country in ISO format.

iso_short_name: &'static str

The short name of the country in ISO format.

languages_official: &'static [&'static str]

The official languages of the country.

languages_spoken: &'static [&'static str]

The spoken languages in the country.

national_destination_code_lengths: &'static [u8]

The national destination code lengths.

national_number_lengths: &'static [u8]

The national number lengths.

national_prefix: Option<&'static str>

The national prefix.

nationality: &'static str

The nationality.

number: &'static str

The country number.

postal_code: bool

Whether the country has a postal code.

postal_code_format: &'static str

The postal code format.

region: &'static str

The region the country is located in.

start_of_week: &'static str

The start of the week in the country.

subregion: &'static str

The subregion the country is located in.

un_locode: &'static str

The UN/LOCODE of the country.

unofficial_names: &'static [&'static str]

The unofficial names of the country.

world_region: &'static str

The world region the country is located in.

Implementations

Source

impl Country

pub fn is_language_official(&self, language: &str) -> bool

Checks if a language is an official language of the country.

pub fn is_language_spoken(&self, language: &str) -> bool

Checks if a language is a spoken language of the country.

pub fn has_language(&self, language: &str) -> bool

Checks if a language is either an official or spoken language of the country.

pub fn is_unofficial_name(&self, name: &str) -> bool

Checks if a name is an unofficial name of the country.

pub fn has_unofficial_name(&self, name: &str) -> bool

Checks if a name is either the short name or an unofficial name of the country.

pub fn is_region(&self, region: &str) -> bool

Checks if a region is the region the country is located in.

pub fn is_subregion(&self, subregion: &str) -> bool

Checks if a subregion is the subregion the country is located in.

pub fn is_region_or_subregion(&self, region_or_subregion: &str) -> bool

Checks if a region is either the region or subregion the country is located in.

pub fn is_region_or_subregion_case_insensitive( &self, region_or_subregion: &str, ) -> bool

Checks if a region is either the region or subregion the country is located in.

pub fn is_in_economic_union(&self, economic_union: &str) -> bool

Checks if the country is part of a specific economic union.

pub fn is_in_economic_union_case_insensitive( &self, economic_union: &str, ) -> bool

Checks if the country is part of a specific economic union.